@@ -4,6 +4,7 @@ test_that("py_finalize() works", {
   file <- tempfile()
 
   callr::r(function(file) {
+    Sys.setenv("RETICULATE_ENABLE_PYTHON_FINALIZER" = "yes")
     library(reticulate)
 
     py_run_string(sprintf("
@@ -14,12 +15,12 @@ class Foo:
     weakref.finalize(self, self.on_finalize)
 
   def on_finalize(self):
-    with open('%s', 'a') as f:
+    with open(r'%s', 'a') as f:
       f.write('Foo.finalize ran\\n')
 
 import atexit
 def on_exit():
-  with open('%s', 'a') as f:
+  with open(r'%s', 'a') as f:
     f.write('on_exit finalizer ran\\n')
 
 atexit.register(on_exit)
