@@ -1,6 +1,7 @@
 context("virtual environments")
 
 test_that("reticulate can bind to virtual environments created with venv", {
+
   skip_if_no_python()
   skip_on_cran()
   skip_on_os("windows")
@@ -8,6 +9,12 @@ test_that("reticulate can bind to virtual environments created with venv", {
   Sys.unsetenv("RETICULATE_PYTHON")
   Sys.unsetenv("RETICULATE_PYTHON_ENV")
 
+  # ensure cacert.pem goes to right folder
+  withr::local_envvar(TMPDIR = tempdir())
+  # this test only verifies venv activation mechanics; package requirement
+  # warnings are covered in test-py_require.R snapshots.
+  withr::local_envvar(RETICULATE_CHECK_REQUIRED_PACKAGES = "false")
+
   # find Python 3 binary for testing
   python3 <- Sys.which("python3")
   if (!nzchar(python3))
